@@ -21,7 +21,7 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -39,29 +39,42 @@
 #define SND_FILE_LOAD		ALOAD_DEVICE_DIRECTORY "aloadC%i"
 #endif
 
-static int snd_card_load1(int card)
+static int snd_card_load2(const char *control)
 {
 	int open_dev;
-	char control[sizeof(SND_FILE_CONTROL) + 10];
-
-	sprintf(control, SND_FILE_CONTROL, card);
+	snd_ctl_card_info_t info;
 
 	open_dev = snd_open_device(control, O_RDONLY);
-#ifdef SUPPORT_ALOAD
-	if (open_dev < 0) {
-		char aload[sizeof(SND_FILE_LOAD) + 10];
-		sprintf(aload, SND_FILE_LOAD, card);
-		open_dev = snd_open_device(aload, O_RDONLY);
-	}
-#endif
 	if (open_dev >= 0) {
-		close (open_dev);
-		return 0;
+		if (ioctl(open_dev, SNDRV_CTL_IOCTL_CARD_INFO, &info) < 0) {
+			int err = -errno;
+			close(open_dev);
+			return err;
+		}
+		close(open_dev);
+		return info.card;
 	} else {
 		return -errno;
 	}
 }
 
+static int snd_card_load1(int card)
+{
+	int res;
+	char control[sizeof(SND_FILE_CONTROL) + 10];
+
+	sprintf(control, SND_FILE_CONTROL, card);
+	res = snd_card_load2(control);
+#ifdef SUPPORT_ALOAD
+	if (res < 0) {
+		char aload[sizeof(SND_FILE_LOAD) + 10];
+		sprintf(aload, SND_FILE_LOAD, card);
+		res = snd_card_load2(aload);
+	}
+#endif
+	return res;
+}
+
 /**
  * \brief Try to load the driver for a card.
  * \param card Card number.
@@ -69,7 +82,7 @@ static int snd_card_load1(int card)
  */
 int snd_card_load(int card)
 {
-	return !!(snd_card_load1(card) == 0);
+	return !!(snd_card_load1(card) >= 0);
 }
 
 /**
@@ -90,7 +103,7 @@ int snd_card_next(int *rcard)
 		return -EINVAL;
 	card = *rcard;
 	card = card < 0 ? 0 : card + 1;
-	for (; card < 32; card++) {
+	for (; card < SND_MAX_CARDS; card++) {
 		if (snd_card_load(card)) {
 			*rcard = card;
 			return 0;
@@ -107,6 +120,7 @@ int snd_card_next(int *rcard)
  *
  * The accepted format is an integer value in ASCII representation
  * or the card identifier (the id parameter for sound-card drivers).
+ * The control device name like /dev/snd/controlC0 is accepted, too.
  */
 int snd_card_get_index(const char *string)
 {
@@ -120,14 +134,16 @@ int snd_card_get_index(const char *string)
 	    (isdigit(*string) && isdigit(*(string + 1)) && *(string + 2) == 0)) {
 		if (sscanf(string, "%i", &card) != 1)
 			return -EINVAL;
-		if (card < 0 || card > 31)
+		if (card < 0 || card >= SND_MAX_CARDS)
 			return -EINVAL;
 		err = snd_card_load1(card);
 		if (err >= 0)
 			return card;
 		return err;
 	}
-	for (card = 0; card < 32; card++) {
+	if (string[0] == '/')	/* device name */
+		return snd_card_load2(string);
+	for (card = 0; card < SND_MAX_CARDS; card++) {
 #ifdef SUPPORT_ALOAD
 		if (! snd_card_load(card))
 			continue;
@@ -150,6 +166,9 @@ int snd_card_get_index(const char *string)
  * \param card Card number
  * \param name Result - card name corresponding to card number
  * \result zero if success, otherwise a negative error code
+ *
+ * The value returned in name is allocated with strdup and should be
+ * freed when no longer used.
  */
 int snd_card_get_name(int card, char **name)
 {
@@ -177,6 +196,9 @@ int snd_card_get_name(int card, char **name)
  * \param card Card number
  * \param name Result - card long name corresponding to card number
  * \result zero if success, otherwise a negative error code
+ *
+ * The value returned in name is allocated with strdup and should be
+ * freed when no longer used.
  */
 int snd_card_get_longname(int card, char **name)
 {
