@@ -71,14 +71,14 @@ static void configuration_filename2(char *fn, size_t fn_len, int format,
 	snprintf(fn, fn_len, "%s/ucm%s/%s/%s%s",
 		 snd_config_topdir(), format >= 2 ? "2" : "",
 		 dir, file, suffix);
-	fn[fn_len-1] = '\0';
 }
 
 static void configuration_filename(snd_use_case_mgr_t *uc_mgr,
 				   char *fn, size_t fn_len,
-				   const char *file, const char *suffix)
+				   const char *dir, const char *file,
+				   const char *suffix)
 {
-	const char *env, *dir;
+	const char *env;
 
 	if (uc_mgr->conf_format > 0) {
 		/* known format */
@@ -94,30 +94,32 @@ static void configuration_filename(snd_use_case_mgr_t *uc_mgr,
 		}
 	}
 	if (env) {
-		snprintf(fn, fn_len, "%s/%s/%s%s",
-			env, uc_mgr->conf_file_name, file, suffix);
-		fn[fn_len-1] = '\0';
+		snprintf(fn, fn_len, "%s/%s/%s%s", env, dir, file, suffix);
 		return;
 	}
 
-	dir = uc_mgr->conf_file_name;
 	if (uc_mgr->conf_format > 0) {
-__format:
 		configuration_filename2(fn, fn_len, uc_mgr->conf_format,
 					dir, file, suffix);
 		return;
 	}
 
 	configuration_filename2(fn, fn_len, 2, dir, file, suffix);
-	if (access(fn, R_OK) == 0)
+	if (access(fn, R_OK) == 0) {
+		/* Found an ucm2 file, only look in the ucm2 dir from now on */
+		uc_mgr->conf_format = 2;
 		return;
+	}
 
 	configuration_filename2(fn, fn_len, 0, dir, file, suffix);
-	if (access(fn, R_OK)) {
-		/* make sure that the error message refers to the new path */
-		uc_mgr->conf_format = 2;
-		goto __format;
+	if (access(fn, R_OK) == 0) {
+		/* Found an ucm1 file, only look in the ucm dir from now on */
+		uc_mgr->conf_format = 1;
+		return;
 	}
+
+	/* make sure that the error message refers to the new path */
+	configuration_filename2(fn, fn_len, 2, dir, file, suffix);
 }
 
 /*
@@ -650,8 +652,10 @@ static int parse_value(snd_use_case_mgr_t *uc_mgr ATTRIBUTE_UNUSED,
 			return -EINVAL;
 		}
 		err = uc_mgr_add_value(base, id, s);
-		if (err < 0)
+		if (err < 0) {
+			free(s);
 			return err;
+		}
 	}
 
 	return 0;
@@ -1179,7 +1183,8 @@ static int parse_verb_file(snd_use_case_mgr_t *uc_mgr,
 	}
 
 	/* open Verb file for reading */
-	configuration_filename(uc_mgr, filename, sizeof(filename), file, "");
+	configuration_filename(uc_mgr, filename, sizeof(filename),
+			       uc_mgr->conf_file_name, file, "");
 	err = uc_mgr_config_load(uc_mgr->conf_format, filename, &cfg);
 	if (err < 0) {
 		uc_error("error: failed to open verb file %s : %d",
@@ -1562,24 +1567,38 @@ static int get_by_card(snd_use_case_mgr_t *mgr, const char *ctl_name, char *long
 }
 
 static int load_master_config(snd_use_case_mgr_t *uc_mgr,
-			      const char *card_name, snd_config_t **cfg, int fcheck)
+			      const char *card_name, snd_config_t **cfg, int longname)
 {
 	char filename[MAX_FILE];
 	int err;
 
 	if (strnlen(card_name, MAX_CARD_LONG_NAME) == MAX_CARD_LONG_NAME) {
-		uc_error("error: invalid card name %s (at most %d chars)\n",
+		uc_error("error: invalid card name %s (at most %d chars)",
 			 card_name, MAX_CARD_LONG_NAME - 1);
 		return -EINVAL;
 	}
 
-	configuration_filename(uc_mgr, filename, sizeof(filename),
-			       card_name, ".conf");
-
-	/* if the configuration file does not exist, silently return */
-	if (fcheck && access(filename, R_OK) != 0)
-		return -ENOENT;
+	uc_mgr->conf_format = 0;
+	if (longname) {
+		if (getenv(ALSA_CONFIG_UCM2_VAR) || !getenv(ALSA_CONFIG_UCM_VAR)) {
+			uc_mgr->conf_format = 2;
+			configuration_filename(uc_mgr, filename, sizeof(filename),
+					       uc_mgr->conf_file_name, card_name, ".conf");
+			if (access(filename, R_OK) == 0)
+				goto __load;
+		}
+		/* try the old ucm directory */
+		uc_mgr->conf_format = 1;
+		configuration_filename(uc_mgr, filename, sizeof(filename),
+				       card_name, card_name, ".conf");
+		if (access(filename, R_OK) != 0)
+			return -ENOENT;
+	} else {
+		configuration_filename(uc_mgr, filename, sizeof(filename),
+				       card_name, card_name, ".conf");
+	}
 
+__load:
 	err = uc_mgr_config_load(uc_mgr->conf_format, filename, cfg);
 	if (err < 0) {
 		uc_error("error: could not parse configuration for card %s",
@@ -1705,11 +1724,10 @@ int uc_mgr_scan_master_configs(const char **_list[])
 	struct dirent **namelist;
 
 	if (env)
-		snprintf(filename, sizeof(filename)-1, "%s", env);
+		snprintf(filename, sizeof(filename), "%s", env);
 	else
-		snprintf(filename, sizeof(filename)-1, "%s/ucm2",
+		snprintf(filename, sizeof(filename), "%s/ucm2",
 			 snd_config_topdir());
-	filename[sizeof(filename)-1] = '\0';
 
 #if defined(_GNU_SOURCE) && !defined(__NetBSD__) && !defined(__FreeBSD__) && !defined(__sun) && !defined(ANDROID)
 #define SORTFUNC	versionsort
@@ -1761,15 +1779,18 @@ int uc_mgr_scan_master_configs(const char **_list[])
 		err = snd_config_search(cfg, "Syntax", &c);
 		if (err < 0) {
 			uc_error("Syntax field not found in %s", d_name);
+			snd_config_delete(cfg);
 			continue;
 		}
 		err = snd_config_get_integer(c, &l);
 		if (err < 0) {
 			uc_error("Syntax field is invalid in %s", d_name);
+			snd_config_delete(cfg);
 			goto __err;
 		}
 		if (l < 2 || l > SYNTAX_VERSION_MAX) {
 			uc_error("Incompatible syntax %d in %s", l, d_name);
+			snd_config_delete(cfg);
 			goto __err;
 		}
 		err = snd_config_search(cfg, "Comment", &c);
