@@ -25,6 +25,8 @@
  */
 
 #include "ucm_local.h"
+#include <sys/stat.h>
+#include <limits.h>
 
 static char *rval_conf_name(snd_use_case_mgr_t *uc_mgr)
 {
@@ -43,6 +45,16 @@ static char *rval_card_id(snd_use_case_mgr_t *uc_mgr)
 	return strdup(snd_ctl_card_info_get_id(ctl_list->ctl_info));
 }
 
+static char *rval_card_driver(snd_use_case_mgr_t *uc_mgr)
+{
+	struct ctl_list *ctl_list;
+
+	ctl_list = uc_mgr_get_one_ctl(uc_mgr);
+	if (ctl_list == NULL)
+		return NULL;
+	return strdup(snd_ctl_card_info_get_driver(ctl_list->ctl_info));
+}
+
 static char *rval_card_name(snd_use_case_mgr_t *uc_mgr)
 {
 	struct ctl_list *ctl_list;
@@ -83,6 +95,56 @@ static char *rval_env(snd_use_case_mgr_t *uc_mgr ATTRIBUTE_UNUSED, const char *i
 	return NULL;
 }
 
+static char *rval_sysfs(snd_use_case_mgr_t *uc_mgr ATTRIBUTE_UNUSED, const char *id)
+{
+	char path[PATH_MAX], link[PATH_MAX + 1];
+	struct stat sb;
+	ssize_t len;
+	char *e;
+	int fd;
+
+	e = getenv("SYSFS_PATH");
+	if (e == NULL)
+		e = "/sys";
+	if (id[0] == '/')
+		id++;
+	snprintf(path, sizeof(path), "%s/%s", e, id);
+	if (lstat(path, &sb) != 0)
+		return NULL;
+	if (S_ISLNK(sb.st_mode)) {
+		len = readlink(path, link, sizeof(link) - 1);
+		if (len <= 0) {
+			uc_error("sysfs: cannot read link '%s' (%d)", path, errno);
+			return NULL;
+		}
+		link[len] = '\0';
+		e = strrchr(link, '/');
+		if (e)
+			return strdup(e + 1);
+		return NULL;
+	}
+	if (S_ISDIR(sb.st_mode))
+		return NULL;
+	if ((sb.st_mode & S_IRUSR) == 0)
+		return NULL;
+
+	fd = open(path, O_RDONLY);
+	if (fd < 0) {
+		uc_error("sysfs open failed for '%s' (%d)", path, errno);
+		return NULL;
+	}
+	len = read(fd, path, sizeof(path)-1);
+	close(fd);
+	if (len < 0) {
+		uc_error("sysfs unable to read value '%s' (%d)", path, errno);
+		return NULL;
+	}
+	while (len > 0 && path[len-1] == '\n')
+		len--;
+	path[len] = '\0';
+	return strdup(path);
+}
+
 #define MATCH_VARIABLE(name, id, fcn)					\
 	if (strncmp((name), (id), sizeof(id) - 1) == 0) { 		\
 		rval = fcn(uc_mgr);					\
@@ -129,10 +191,12 @@ int uc_mgr_get_substituted_value(snd_use_case_mgr_t *uc_mgr,
 		if (*value == '$' && *(value+1) == '{') {
 			MATCH_VARIABLE(value, "${ConfName}", rval_conf_name);
 			MATCH_VARIABLE(value, "${CardId}", rval_card_id);
+			MATCH_VARIABLE(value, "${CardDriver}", rval_card_driver);
 			MATCH_VARIABLE(value, "${CardName}", rval_card_name);
 			MATCH_VARIABLE(value, "${CardLongName}", rval_card_longname);
 			MATCH_VARIABLE(value, "${CardComponents}", rval_card_components);
 			MATCH_VARIABLE2(value, "${env:", rval_env);
+			MATCH_VARIABLE2(value, "${sys:", rval_sysfs);
 			err = -EINVAL;
 			tmp = strchr(value, '}');
 			if (tmp) {
